import * as vscode from "vscode";
import * as path from "path";
import * as fs from "fs";
import { RegexpItem } from './mode';
import { Storage } from "./storage";

export class ExecutorView  implements vscode.WebviewViewProvider  {
     static readonly viewType = "regexcutor.excutor";
    private _view?: vscode.WebviewView;
    constructor(private context: vscode.ExtensionContext, private readonly _storage: Storage) {
 
        console.log("constructor:------------");
    }
    private getResourcePath(relativePath: string): vscode.Uri {
        return vscode.Uri.file(path.join(this.context.extensionPath, relativePath));
    }
    private getResourceUri(relativePath: string): vscode.Uri|undefined {
        return this._view?.webview.asWebviewUri(this.getResourcePath(relativePath));
    }
    resolveWebviewView(webviewView: vscode.WebviewView, context: vscode.WebviewViewResolveContext, token: vscode.CancellationToken): Thenable<void> | void {
        webviewView.webview.options = { enableScripts: true };
        this._view = webviewView;
        
        webviewView.webview.html = this.generateHtml(webviewView);
        webviewView.webview.onDidReceiveMessage(message => {
            if(message.command === "regex.save"){
                const item:RegexpItem = {
                    name:message.name,
                    regexp:message.regexp,
                    teststr:message.teststr
                };
                this._storage.addItem(item);
            }
        });
    }
    generateHtml(webviewView: vscode.WebviewView): string {
        const indexUri = this.getResourcePath("media/index.html");
        const indexWebUri = this.getResourceUri("media/index.html");
        if(!indexWebUri){
           vscode.window.showErrorMessage("index.html not found");
           return "";
        }
        const root = path.dirname(indexWebUri?.toString());
        const indexHtml = fs.readFileSync(indexUri?.fsPath||'', 'utf-8');
        const indexHtmlWithRoot = indexHtml.replace(/##ROOT##/g, root)
        return indexHtmlWithRoot;
    }

    displayRegx(reg:RegexpItem) {
        const command = Object.assign(reg,{command:"regex.show"});
        this._view?.webview.postMessage(command);
    }

}