// The module 'vscode' contains the VS Code extensibility API
// Import the module and reference it with the alias vscode in your code below
import * as vscode from 'vscode';
import { Storage } from './storage';
import { ListProvider } from './list.provider';
import { ExecutorView } from './excutor.view';
import { RegexpItem } from './mode';
// This method is called when your extension is activated
// Your extension is activated the very first time the command is executed
export function activate(context: vscode.ExtensionContext) {
	const storage = new Storage();
	const commandReg = vscode.commands.registerCommand('regexcutor.delete', (item: RegexpItem) => {
		storage.removeItem(item);
	});
	const listProvider = new ListProvider(storage);
	const executorView = new ExecutorView(context,storage);
	context.subscriptions.push(vscode.window.registerWebviewViewProvider(ExecutorView.viewType, executorView));
	const listView = vscode.window.createTreeView('regexcutor.list', {
		treeDataProvider: listProvider
	});
	listView.onDidChangeSelection((e) => {
		if (e.selection.length === 1) {
			const item = e.selection[0];
			executorView.displayRegx(item);
		}
	});
	
	context.subscriptions.push(listView);
}

// This method is called when your extension is deactivated
export function deactivate() {}
