import * as vscode from "vscode";
import { RegexpItem } from './mode';
import { Storage } from "./storage";

export class ReTreeItem extends vscode.TreeItem {
    constructor(
        public readonly label: string,
        public readonly collapsibleState: vscode.TreeItemCollapsibleState,
        private item: RegexpItem
    ) {
        super(label, collapsibleState);
        // this.command = {
        //     command: 'regexcutor.delete',
        //     title: '删除',
        //     arguments: [this.item]
        // };
    }
}

export class ListProvider implements vscode.TreeDataProvider<RegexpItem> {
    private items: RegexpItem[] = [];
    private _onDidChangeTreeData: vscode.EventEmitter<RegexpItem | undefined | null | void> = new vscode.EventEmitter<RegexpItem | undefined | null | void>();
    onDidChangeTreeData?: vscode.Event<void | RegexpItem | RegexpItem | null | undefined> | undefined = this._onDidChangeTreeData.event;

    getTreeItem(element: RegexpItem): ReTreeItem | Thenable<ReTreeItem> {
        return new ReTreeItem(element.name, vscode.TreeItemCollapsibleState.None, element);
    }

    getChildren(element?: RegexpItem | undefined): vscode.ProviderResult<RegexpItem[]> {
        return this.items;
    }



    constructor(private storage: Storage) {
        this.storage.on('changed', () => {
            this.load()
        });
        this.load();
    }

    load() {
        this.items = this.storage.getItems();
        this._onDidChangeTreeData?.fire();
    }
}
