import * as os from 'os';
import * as fs from 'fs';
import * as path from 'path';
import { RegexpItem } from './mode';
import { EventEmitter } from "events";
export class Storage extends EventEmitter{
    private storagePath: string = path.join(os.homedir(), '.vscode', 'regexp.json');
    private items: RegexpItem[] = [];
    constructor() {
        super()
        if (!fs.existsSync(this.storagePath)) {
            fs.writeFileSync(this.storagePath, '[]');
        }
        this.load();
    }

    load() {
        this.items = JSON.parse(fs.readFileSync(this.storagePath, 'utf-8'));
    }

    getItems() {
        return this.items;
    }
    addItem(item: RegexpItem) {
        this.items.push(item);
        this.save();
        this.emit('changed');
    }
    removeItem(item: RegexpItem) {
        const index = this.items.findIndex(i => {
           return  i.name === item.name && i.regexp === item.regexp;
        });
        if(index === -1){
            return;
        }
        this.items.splice(index, 1);
        this.save();
        this.emit('changed');
    }
    save() {
        fs.writeFileSync(this.storagePath, JSON.stringify(this.items));
    }
}